unit uImplDLL_WIKA_P30;

interface

uses
  Windows, SysUtils;

type
  tDeviceInfo = record
    SerialNumber    : AnsiString;
    ProductNumber   : AnsiString;
    FirmwareVersion : AnsiString;
    RangeStart      : single;
    RangeEnd        : single;
    UnitStart       : AnsiString;
    UnitEnd         : AnsiString;
    IsAbsolute      : WordBool;
    ProductionD     : byte;
    ProductionM     : byte;
    ProductionY     : byte;
  end;

type
  tP30_OpenPort = function(const pCOM: SmallInt): SmallInt; stdcall;
  tP30_ClosePort = function(const pHandle: byte): SmallInt; stdcall;

  tP30_ReadDeviceInfo = function(const pHandle: byte;
    out pDeviceInfo: tDeviceInfo): SmallInt; stdcall;

  tP30_ReadSingle = function(const pHandle: byte;
    out pValue: Single): SmallInt; stdcall;

  tP30_ReadDllVersion = function(): SmallInt; stdcall;

  tP30_SetToAdjust = function(const pHandle, pToAdjust: byte): SmallInt;
    stdcall;
  tP30_SetAdjust = function(
    const pHandle, pToAdjust, pAdjustVal: byte): SmallInt; stdcall;

  tP30_ReadCalibDate = function(const pHandle: byte;
    out pDD, pMM, pYY: byte): SmallInt; stdcall;
  tP30_WriteCalibDate = function(
    const pHandle, pDD, pMM, pYY: byte): SmallInt; stdcall;

  tP30_SetOperatingMode = function(const pHandle: byte;
    const pPermanent: WordBool; const pOperatingMode: byte): SmallInt; stdcall;
  tP30_SetCyclicInterval = function(const pHandle: byte;
    const pPermanent: WordBool; const pInterval: word): SmallInt; stdcall;

var
  P30_ReadDllVersion: tP30_ReadDllVersion;
  P30_OpenPort: tP30_OpenPort;
  P30_ClosePort: tP30_ClosePort;
  P30_ReadDeviceInfo: tP30_ReadDeviceInfo;
  P30_ReadPressure: tP30_ReadSingle;
  P30_ReadTemperature: tP30_ReadSingle;
  P30_EnableAdjustment: tP30_SetToAdjust;
  P30_StoreAdjustment: tP30_SetToAdjust;
  P30_RestoreAdjustment: tP30_SetToAdjust;
  P30_IncAdjustment: tP30_SetAdjust;
  P30_DecAdjustment: tP30_SetAdjust;
  P30_ReadLastCalibrationDate: tP30_ReadCalibDate;
  P30_ReadNextCalibrationDate: tP30_ReadCalibDate;
  P30_WriteLastCalibrationDate: tP30_WriteCalibDate;
  P30_WriteNextCalibrationDate: tP30_WriteCalibDate;
  P30_SetOperatingMode: tP30_SetOperatingMode;
  P30_SetCyclicInterval: tP30_SetCyclicInterval;

procedure InitDLLroutines;

implementation

var
  HandleDLL: THandle;

procedure InitDLLroutines;

  function GetAddr(const pProcName: PChar): pointer;
  //Ermittelt die Adresse in der DLL
  //und berprft, ob die Prozedur gefunden wurde
  begin
    Result := GetProcAddress(HandleDLL, pProcName);
    if NOT assigned(Result) then
      raise Exception.Create('Die Prozeduradresse von "' + pProcName
       + '" konnte nicht ermittelt werden!');
  end;

begin
  if (HandleDLL = 0) then
  begin
    HandleDLL := LoadLibrary('WIKA_P30.DLL');

    if (HandleDLL >= HInstance_Error) then
    begin
      P30_ReadDllVersion := GetAddr('ReadDllVersion');
      P30_OpenPort := GetAddr('OpenPort');
      P30_ClosePort := GetAddr('ClosePort');
      P30_ReadDeviceInfo := GetAddr('ReadDeviceInfo');
      P30_ReadPressure := GetAddr('ReadPressure');
      P30_ReadTemperature := GetAddr('ReadTemperature');
      P30_EnableAdjustment := GetAddr('EnableAdjustment');
      P30_StoreAdjustment := GetAddr('StoreAdjustment');
      P30_RestoreAdjustment := GetAddr('RestoreAdjustment');
      P30_IncAdjustment := GetAddr('IncAdjustment');
      P30_DecAdjustment := GetAddr('DecAdjustment');
      P30_ReadLastCalibrationDate := GetAddr('ReadLastCalibrationDate');
      P30_ReadNextCalibrationDate := GetAddr('ReadNextCalibrationDate');
      P30_WriteLastCalibrationDate := GetAddr('WriteLastCalibrationDate');
      P30_WriteNextCalibrationDate := GetAddr('WriteNextCalibrationDate');
      P30_SetOperatingMode := GetAddr('SetOperatingMode');
      P30_SetCyclicInterval := GetAddr('SetCyclicInterval');
    end;
  end;
end;

initialization
  HandleDLL := 0;
finalization;
  if (HandleDLL <> 0) then
    FreeLibrary(HandleDLL);
end.
